@@ -1,13 +1,13 @@
-__version__ = "1.1.6"
+__version__ = "1.1.8"
 from ._coordinates import BranchingType, SphericalCoordinates, get_child, get_parent
 from ._creation import (
-    c_spherical,
-    from_branching_types,
-    hopf,
-    polar,
-    random,
-    standard,
-    standard_prime,
+    create_from_branching_types,
+    create_hopf,
+    create_polar,
+    create_random,
+    create_spherical,
+    create_standard,
+    create_standard_prime,
 )
 from ._draw import draw
 from ._integral import integrate, roots
@@ -25,25 +25,25 @@ from .special import (
 __all__ = [
     "BranchingType",
     "SphericalCoordinates",
-    "c_spherical",
+    "create_from_branching_types",
+    "create_hopf",
+    "create_polar",
+    "create_random",
+    "create_random",
+    "create_spherical",
+    "create_standard",
+    "create_standard_prime",
     "draw",
-    "from_branching_types",
     "fundamental_solution",
     "get_child",
     "get_parent",
-    "hopf",
     "integrate",
-    "polar",
     "potential_coef",
-    "random",
-    "random",
     "random_ball",
     "roots",
     "shn1",
     "shn2",
     "sjv",
-    "standard",
-    "standard_prime",
     "syv",
     "szv",
 ]
