@@ -25,9 +25,14 @@ def roots(
     dtype: Any | None = None,
     xp: ArrayNamespaceFull,
 ) -> tuple[Mapping[TSpherical, Array], Mapping[TSpherical, Array]]:
-    """
+    r"""
     Gauss-Jacobi quadrature roots and weights.
 
+    .. math::
+        \int_\mathbb{S}^{d-1} f d\omega^{d-1} \approx
+        \sum_{(\theta_1, w_1)} w_1 \cdots \sum_{(\theta_{d-1}, w_{d-1})} w_{d-1}
+        f(\theta_1, \ldots, \theta_{d-1})
+
     Parameters
     ----------
     n : int
@@ -145,9 +150,12 @@ def integrate(
     device: Any | None = None,
     dtype: Any | None = None,
 ) -> Array | Mapping[TSpherical, Array]:
-    """
+    r"""
     Integrate the function over the hypersphere.
 
+    .. math::
+        \int_{\mathbb{S}^{d-1}} f d\omega^{d-1}
+
     Parameters
     ----------
     f : Callable[ [Mapping[TSpherical, Array]], Mapping[TSpherical, Array] | Array, ] | Mapping[TSpherical, Array] | Array # noqa: E501
