@@ -1,10 +1,8 @@
 from ._bessel import shn1, shn2, sjv, syv, szv
 from ._helmholtz import fundamental_solution, potential_coef
-from ._lgamma import lgamma
 
 __all__ = [
     "fundamental_solution",
-    "lgamma",
     "potential_coef",
     "shn1",
     "shn2",
