@@ -1,9 +1,7 @@
 from typing import Literal, TypeVar
 
 from array_api._2024_12 import Array
-from array_api_compat import (
-    array_namespace,
-)
+from array_api_compat import array_namespace, to_device
 from scipy.special import hankel1, hankel2, jv, jvp, yv, yvp
 
 TArray = TypeVar("TArray", bound=Array)
@@ -16,9 +14,12 @@ def szv(
     type: Literal["j", "y", "h1", "h2"],
     derivative: bool = False,
 ) -> TArray:
-    """
+    r"""
     Utility function to compute hyperspherical functions.
 
+    .. math::
+        f_v^{(d)} (z) = \sqrt{\frac{\pi}{2}} \frac{F_{v + d/2 - 1}(z)}{z^{d/2 - 1}}
+
     Parameters
     ----------
     v : TArray
@@ -38,6 +39,11 @@ def szv(
     TArray
         The hyperspherical function.
 
+    References
+    ----------
+    McLean, W. (2000). Strongly Elliptic Systems and
+    Boundary Integral Equations. p.279
+
     """
 
     xp = array_namespace(v, d, z)
@@ -75,7 +81,11 @@ def szv(
         dtype = xp.result_type(dtype, xp.complex64)
     return (
         xp.sqrt(xp.asarray(xp.pi / 2, device=z.device, dtype=dtype))
-        * xp.asarray(zv(v + d_half_minus_1, z), device=z.device, dtype=dtype)
+        * xp.asarray(
+            zv(to_device(v + d_half_minus_1, "cpu"), to_device(z, "cpu")),
+            device=z.device,
+            dtype=dtype,
+        )
         / (z**d_half_minus_1)
     )
 
@@ -86,9 +96,12 @@ def sjv(
     z: TArray,
     derivative: bool = False,
 ) -> TArray:
-    """
+    r"""
     Hyperspherical Bessel function of the first kind.
 
+    .. math::
+        j_v^{(d)} (z) = \sqrt{\frac{\pi}{2}} \frac{J_{v + d/2 - 1}(z)}{z^{d/2 - 1}}
+
     Parameters
     ----------
     v : TArray
@@ -121,9 +134,12 @@ def syv(
     z: TArray,
     derivative: bool = False,
 ) -> TArray:
-    """
+    r"""
     Hyperspherical Bessel function of the second kind.
 
+    .. math::
+        y_v^{(d)} (z) = \sqrt{\frac{\pi}{2}} \frac{Y_{v + d/2 - 1}(z)}{z^{d/2 - 1}}
+
     Parameters
     ----------
     v : TArray
@@ -156,9 +172,12 @@ def shn1(
     z: TArray,
     derivative: bool = False,
 ) -> TArray:
-    """
+    r"""
     Hyperspherical Hankel function of the first kind.
 
+    .. math::
+        h_v^{(1)(d)} (z) = \sqrt{\frac{\pi}{2}} \frac{H^{(1)}_{v + d/2 - 1}(z)}{z^{d/2 - 1}}
+
     Parameters
     ----------
     v : TArray
@@ -186,9 +205,12 @@ def shn2(
     z: TArray,
     derivative: bool = False,
 ) -> TArray:
-    """
+    r"""
     Hyperspherical Hankel function of the second kind.
 
+    .. math::
+        h_v^{(2)(d)} (z) = \sqrt{\frac{\pi}{2}} \frac{H^{(2)}_{v + d/2 - 1}(z)}{z^{d/2 - 1}}
+
     Parameters
     ----------
     v : TArray
