@@ -4,7 +4,13 @@ import pytest
 from matplotlib import pyplot as plt
 
 from ultrasphere._coordinates import SphericalCoordinates
-from ultrasphere._creation import c_spherical, hopf, random
+from ultrasphere._creation import (
+    create_hopf,
+    create_random,
+    create_spherical,
+    create_standard,
+    create_standard_prime,
+)
 from ultrasphere._draw import draw
 
 PATH = Path("tests/.cache/")
@@ -14,10 +20,12 @@ Path.mkdir(PATH, exist_ok=True)
 @pytest.mark.parametrize(
     "name, c",
     [
-        ("spherical", c_spherical()),
-        ("hoph", hopf(3)),
-        ("random-1", random(1)),
-        ("random-10", random(10)),
+        ("spherical", create_spherical()),
+        ("hoph", create_hopf(3)),
+        ("standard-4", create_standard(4)),
+        ("standard-prime-4", create_standard_prime(4)),
+        ("random-1", create_random(1)),
+        ("random-10", create_random(10)),
     ],
 )
 def test_draw(name: str, c: SphericalCoordinates[str, int]) -> None:
